@@ -2,27 +2,21 @@
 svymean_trimmed <- function(x, design, LB = 0.05, UB = 1 - LB, na.rm = FALSE,
                             ...)
 {
-    if (!is.language(x))
-        stop("Argument 'x' must be a formula object\n", call. = FALSE)
     dat <- .check_formula(x, design, na.rm)
     # in the presence of NA's
     if (dat$failure)
         return(.new_svystat_rob("mean", dat$yname,
             paste0("Weighted trimmed estimator (", LB, ", ", UB, ")"),
-            dat$domain, dat$design, match.call(), "trim", LB = LB, UB = UB))
+            dat$design, match.call(), "trim", LB = LB, UB = UB))
 
-    # population- vs. domain-level estimate
-    res <- if (dat$domain)
-        weighted_mean_trimmed(dat$y[dat$in_domain], dat$w[dat$in_domain], LB,
-                              UB, TRUE, FALSE)
-    else
-        weighted_mean_trimmed(dat$y, dat$w, LB, UB, TRUE, FALSE)
+    res <- weighted_mean_trimmed(dat$y, dat$w, LB, UB, TRUE, FALSE)
 
     # influence function
     infl <- .infl_trimmed(res$model$y, res$model$w, LB, UB, res$estimate) *
                 res$model$w / sum(res$model$w)
-    if (dat$domain) {
-        tmp <- numeric(dat$n)
+
+    if (dat$calibrated) {
+        tmp <- numeric(length(dat$in_domain))
         tmp[dat$in_domain] <- infl
         infl <- tmp
     }
@@ -33,7 +27,6 @@ svymean_trimmed <- function(x, design, LB = 0.05, UB = 1 - LB, na.rm = FALSE,
                               postStrata = design$postStrata)
     # return
     names(res$estimate) <- dat$yname
-    res$estimator$domain <- dat$domain
     res$design <- dat$design
     res$call <- match.call()
     class(res) <- "svystat_rob"
@@ -43,26 +36,19 @@ svymean_trimmed <- function(x, design, LB = 0.05, UB = 1 - LB, na.rm = FALSE,
 svytotal_trimmed <- function(x, design, LB = 0.05, UB = 1 - LB, na.rm = FALSE,
                              ...)
 {
-    if (!is.language(x))
-        stop("Argument 'x' must be a formula object\n", call. = FALSE)
     dat <- .check_formula(x, design, na.rm)
     # in the presence of NA's
     if (dat$failure)
         return(.new_svystat_rob("total", dat$yname,
             paste0("Weighted trimmed estimator (", LB, ", ", UB, ")"),
-            dat$domain, dat$design, match.call(), "trim", LB = LB, UB = UB))
+            dat$design, match.call(), "trim", LB = LB, UB = UB))
 
-    # population- vs. domain-level estimate
-    res <- if (dat$domain)
-        weighted_total_trimmed(dat$y[dat$in_domain], dat$w[dat$in_domain], LB,
-                               UB, TRUE, FALSE)
-    else
-        weighted_total_trimmed(dat$y, dat$w, LB, UB, TRUE, FALSE)
+    res <- weighted_total_trimmed(dat$y, dat$w, LB, UB, TRUE, FALSE)
 
     # influence function
     infl <- .infl_trimmed(res$model$y, res$model$w, LB, UB, 0) * res$model$w
-    if (dat$domain) {
-        tmp <- numeric(dat$n)
+    if (dat$calibrated) {
+        tmp <- numeric(length(dat$in_domain))
         tmp[dat$in_domain] <- infl
         infl <- tmp
     }
@@ -73,7 +59,6 @@ svytotal_trimmed <- function(x, design, LB = 0.05, UB = 1 - LB, na.rm = FALSE,
                               postStrata = design$postStrata)
     # return
     names(res$estimate) <- dat$yname
-    res$estimator$domain <- dat$domain
     res$design <- dat$design
     res$call <- match.call()
     class(res) <- "svystat_rob"
